@@ -18,9 +18,9 @@ install_requirements(){
     # TODO: if not [automake --version]
     if [ "$os" == "Linux" ]; then
         if [ "$(grep -Ei 'debian|buntu|mint' /etc/*release)" ]; then
-            $sudo apt-get update && $sudo apt-get install -y build-essential wget python3-devel
+            $sudo apt-get update && $sudo apt-get install -y build-essential curl python3-devel
         elif [ "$(grep -Ei 'fedora|redhat' /etc/*release)" ]; then
-            $sudo yum groupinstall -y  'Development Tools' -y && $sudo yum install -y wget python3-devel
+            $sudo yum groupinstall -y 'Development Tools' && $sudo yum install -y curl python3-devel
         fi
     elif [ "$os" == "Darwin" ]; then
         if [[ $(command -v brew) == "" ]]; then
@@ -28,7 +28,7 @@ install_requirements(){
             echo "Try https://brew.sh/"
             exit 0
         fi
-        brew install wget
+        brew install curl
     fi
 }
 
